# Ribbon theme for Shower HTML presentation engine

Follow [@shower_me](https://twitter.com/shower_me) for support and updates

To see Ribbon theme for Shower in action:

- Open [shwr.me/shower/themes/ribbon](http://shwr.me/shower/themes/ribbon/)
- Click any slide to enter presentation mode
- Use arrow keys or presenter remote to navigate
- Press `Esc` to exit presentation mode

Part of [Shower presentation template](https://github.com/shower/shower/). See [Wiki](https://github.com/shower/shower/wiki) for more information how to use Shower.

---
Licensed under [MIT License](http://en.wikipedia.org/wiki/MIT_License), see [license page](https://github.com/shower/shower/wiki/MIT-License) for details.